This package contains utilities for :
- mplExtended : functions extending the matplotlib package
- configFilesD : a template configuration source code that runs backend computations for dash server
- dccExtendedD : functions that extend the dash packages
- templateDashD : dash Template.
- templateTabsD : predefined dash tabs
- utilsD : convenient functions that speed up and help building codes more concise  
